@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Open::This;
 
-our $VERSION = '0.000026';
+our $VERSION = '0.000027';
 
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(
@@ -26,6 +26,10 @@ use URI ();
 sub parse_text {
     my $text = join q{ }, @_;
 
+    if ($text) {
+        $text =~ s/^\s+|\s+$//g;
+    }
+
     return undef if !$text;
     my %parsed = ( original_text => $text );
 
@@ -336,7 +340,7 @@ Open::This - Try to Do the Right Thing when opening files
 
 =head1 VERSION
 
-version 0.000026
+version 0.000027
 
 =head1 DESCRIPTION
 
